==> haskell-nettle-0.2.0-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-nettle.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nettle
version: 0.2.0
id: nettle-0.2.0-AOWpnprs1h3Ipr0Si7Ri5C
key: nettle-0.2.0-AOWpnprs1h3Ipr0Si7Ri5C
license: MIT
copyright: Stefan Bühler <stbuehler@web.de>
maintainer: Stefan Bühler <stbuehler@web.de>
homepage: https://github.com/stbuehler/haskell-nettle
synopsis: safe nettle binding
description:
    safe binding for the nettle (<http://www.lysator.liu.se/~nisse/nettle/nettle.html>) library.
    Tested with 3.1.1, might work with 3.0, does NOT WORK with 2.x.
category: Cryptography
author: Stefan Bühler <stbuehler@web.de>
exposed: True
exposed-modules:
    Crypto.Nettle.ChaChaPoly1305 Crypto.Nettle.Ciphers
    Crypto.Nettle.CCM Crypto.Nettle.Hash Crypto.Nettle.KeyedHash
    Crypto.Nettle.HMAC Crypto.Nettle.UMAC
hidden-modules: Crypto.Nettle.Ciphers.Internal
                Crypto.Nettle.Ciphers.ForeignImports
                Crypto.Nettle.Hash.ForeignImports Crypto.Nettle.Hash.Types
                Nettle.Utils
abi: 32906e246e09af4ff1161706977770b6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/nettle-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/nettle-0.2.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/nettle-0.2.0
hs-libraries: HSnettle-0.2.0-AOWpnprs1h3Ipr0Si7Ri5C
extra-libraries:
    nettle
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1
    crypto-cipher-types-0.0.9-KCUUibYwQfd3mN2Luf0nrN
    securemem-0.1.9-EejLErvjcTFDEKlSmM4Et1
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
haddock-interfaces: /usr/share/doc/haskell-nettle/html/nettle.haddock
haddock-html: /usr/share/doc/haskell-nettle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nettle-0.2.0-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-nettle.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nettle
version: 0.2.0
id: nettle-0.2.0-A0V4arJkvEuAMukdD6B3Ro
key: nettle-0.2.0-A0V4arJkvEuAMukdD6B3Ro
license: MIT
copyright: Stefan Bühler <stbuehler@web.de>
maintainer: Stefan Bühler <stbuehler@web.de>
homepage: https://github.com/stbuehler/haskell-nettle
synopsis: safe nettle binding
description:
    safe binding for the nettle (<http://www.lysator.liu.se/~nisse/nettle/nettle.html>) library.
    Tested with 3.1.1, might work with 3.0, does NOT WORK with 2.x.
category: Cryptography
author: Stefan Bühler <stbuehler@web.de>
exposed: True
exposed-modules:
    Crypto.Nettle.ChaChaPoly1305 Crypto.Nettle.Ciphers
    Crypto.Nettle.CCM Crypto.Nettle.Hash Crypto.Nettle.KeyedHash
    Crypto.Nettle.HMAC Crypto.Nettle.UMAC
hidden-modules: Crypto.Nettle.Ciphers.Internal
                Crypto.Nettle.Ciphers.ForeignImports
                Crypto.Nettle.Hash.ForeignImports Crypto.Nettle.Hash.Types
                Nettle.Utils
abi: e5a69ffcd777d48dccf9719bb6db32d4
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/nettle-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/nettle-0.2.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/nettle-0.2.0
hs-libraries: HSnettle-0.2.0-A0V4arJkvEuAMukdD6B3Ro
extra-libraries:
    nettle
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1
    crypto-cipher-types-0.0.9-AfrbXuzMbdh1qMQIWJkaB4
    securemem-0.1.9-27iPpKEc5cx9pB9GAggjZj
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
haddock-interfaces: /usr/share/doc/haskell-nettle/html/nettle.haddock
haddock-html: /usr/share/doc/haskell-nettle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
